These helpers make waits explicit in tests and require finite
timeouts for tasks and streams. rho_test_agent() constructs a deterministic
faux-provider agent fixture.
These helpers make waits explicit in tests and require finite
timeouts for tasks and streams. rho_test_agent() constructs a deterministic
faux-provider agent fixture.